==> miria-monitor-api-0.0.2-20180810.014025-14-sources.jar: cn/com/duiba/miria/monitor/api/entity/TemplateTriggerRelation.java <==
package cn.com.duiba.miria.monitor.api.entity;

import java.util.Date;
import javax.persistence.*;

@Table(name = "tb_template_trigger_relation")
public class TemplateTriggerRelation {
    /**
     * 主键id
     */
    @Id
    private Long id;

    /**
     * 模板id,tb_trigger_template.id
     */
    @Column(name = "template_id")
    private Long templateId;

    /**
     * 触发器,tb_trigger.id
     */
    @Column(name = "trigger_id")
    private Long triggerId;

    /**
     * 创建时间
     */
    @Column(name = "gmt_create")
    private Date gmtCreate;

    /**
     * 修改时间
     */
    @Column(name = "gmt_modified")
    private Date gmtModified;

    /**
     * 获取主键id
     *
     * @return id - 主键id
     */
    public Long getId() {
        return id;
    }

    /**
     * 设置主键id
     *
     * @param id 主键id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * 获取模板id,tb_trigger_template.id
     *
     * @return template_id - 模板id,tb_trigger_template.id
     */
    public Long getTemplateId() {
        return templateId;
    }

    /**
     * 设置模板id,tb_trigger_template.id
     *
     * @param templateId 模板id,tb_trigger_template.id
     */
    public void setTemplateId(Long templateId) {
        this.templateId = templateId;
    }

    /**
     * 获取触发器,tb_trigger.id
     *
     * @return trigger_id - 触发器,tb_trigger.id
     */
    public Long getTriggerId() {
        return triggerId;
    }

    /**
     * 设置触发器,tb_trigger.id
     *
     * @param triggerId 触发器,tb_trigger.id
     */
    public void setTriggerId(Long triggerId) {
        this.triggerId = triggerId;
    }

    /**
     * 获取创建时间
     *
     * @return gmt_create - 创建时间
     */
    public Date getGmtCreate() {
        return gmtCreate;
    }

    /**
     * 设置创建时间
     *
     * @param gmtCreate 创建时间
     */
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    /**
     * 获取修改时间
     *
     * @return gmt_modified - 修改时间
     */
    public Date getGmtModified() {
        return gmtModified;
    }

    /**
     * 设置修改时间
     *
     * @param gmtModified 修改时间
     */
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> miria-monitor-api-1.0.12-sources.jar: cn/com/duiba/miria/monitor/api/entity/TemplateTriggerRelation.java <==
package cn.com.duiba.miria.monitor.api.entity;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

@Table(name = "tb_template_trigger_relation")
public class TemplateTriggerRelation {
    /**
     * 主键id
     */
    @Id
    private Long id;

    /**
     * 模板id,tb_trigger_template.id
     */
    @Column(name = "template_id")
    private Long templateId;

    /**
     * 触发器,tb_trigger.id
     */
    @Column(name = "trigger_id")
    private Long triggerId;

    /**
     * 创建时间
     */
    @Column(name = "gmt_create")
    private Date gmtCreate;

    /**
     * 修改时间
     */
    @Column(name = "gmt_modified")
    private Date gmtModified;

    /**
     * 获取主键id
     *
     * @return id - 主键id
     */
    public Long getId() {
        return id;
    }

    /**
     * 设置主键id
     *
     * @param id 主键id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * 获取模板id,tb_trigger_template.id
     *
     * @return template_id - 模板id,tb_trigger_template.id
     */
    public Long getTemplateId() {
        return templateId;
    }

    /**
     * 设置模板id,tb_trigger_template.id
     *
     * @param templateId 模板id,tb_trigger_template.id
     */
    public void setTemplateId(Long templateId) {
        this.templateId = templateId;
    }

    /**
     * 获取触发器,tb_trigger.id
     *
     * @return trigger_id - 触发器,tb_trigger.id
     */
    public Long getTriggerId() {
        return triggerId;
    }

    /**
     * 设置触发器,tb_trigger.id
     *
     * @param triggerId 触发器,tb_trigger.id
     */
    public void setTriggerId(Long triggerId) {
        this.triggerId = triggerId;
    }

    /**
     * 获取创建时间
     *
     * @return gmt_create - 创建时间
     */
    public Date getGmtCreate() {
        return gmtCreate;
    }

    /**
     * 设置创建时间
     *
     * @param gmtCreate 创建时间
     */
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    /**
     * 获取修改时间
     *
     * @return gmt_modified - 修改时间
     */
    public Date getGmtModified() {
        return gmtModified;
    }

    /**
     * 设置修改时间
     *
     * @param gmtModified 修改时间
     */
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
